@@ -1,21 +1,23 @@
 import concurrent.futures
 import os
 import re
+import shutil
 import tempfile
 from contextlib import contextmanager
-from typing import Iterable, Iterator, List, Optional, Set
+from pathlib import Path
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Set
 
 import click
 from pygitguardian import GGClient
 
+from ggshield.config import CPU_COUNT, Cache, Config
+from ggshield.config_types import IgnoredMatch
+from ggshield.git_shell import GIT_PATH, get_list_commit_SHA, is_git_dir, shell
 from ggshield.output import OutputHandler
-from ggshield.scan import Commit, ScanCollection
+from ggshield.path import get_files_from_paths
+from ggshield.scan import Commit, Files, Result, ScanCollection
 from ggshield.text_utils import STYLE, format_text
-
-from .config import CPU_COUNT, Cache, Config
-from .git_shell import GIT_PATH, get_list_commit_SHA, is_git_dir, shell
-from .path import get_files_from_paths
-from .utils import REGEX_GIT_URL, SupportedScanMode, handle_exception
+from ggshield.utils import REGEX_GIT_URL, SupportedScanMode, handle_exception
 
 
 @contextmanager
@@ -186,7 +188,7 @@ def scan_commit(
     client: GGClient,
     cache: Cache,
     verbose: bool,
-    matches_ignore: Iterable[str],
+    matches_ignore: Iterable[IgnoredMatch],
     all_policies: bool,
     mode_header: str,
     banlisted_detectors: Optional[Set[str]] = None,
@@ -217,7 +219,7 @@ def scan_commit_range(
     output_handler: OutputHandler,
     verbose: bool,
     exclusion_regexes: Set[re.Pattern],
-    matches_ignore: Iterable[str],
+    matches_ignore: Iterable[IgnoredMatch],
     all_policies: bool,
     scan_id: str,
     mode_header: str,
@@ -262,3 +264,52 @@ def scan_commit_range(
             ScanCollection(id=scan_id, type="commit-range", scans=scans)
         )
     return return_code
+
+
+@click.command()
+@click.argument(
+    "path", nargs=1, type=click.Path(exists=True, resolve_path=True), required=True
+)
+@click.pass_context
+def archive_cmd(ctx: click.Context, path: str) -> int:  # pragma: no cover
+    """
+    scan archive <PATH>.
+    """
+    with tempfile.TemporaryDirectory(suffix="ggshield") as temp_dir:
+        try:
+            shutil.unpack_archive(path, extract_dir=Path(temp_dir))
+        except Exception as exn:
+            raise click.ClickException(f'Failed to unpack "{path}" archive: {exn}')
+
+        config: Config = ctx.obj["config"]
+        files: Files = get_files_from_paths(
+            paths=[temp_dir],
+            exclusion_regexes=ctx.obj["exclusion_regexes"],
+            recursive=True,
+            yes=True,
+            verbose=config.verbose,
+            ignore_git=True,
+        )
+
+        with click.progressbar(
+            length=len(files.files), label="Scanning"
+        ) as progressbar:
+
+            def update_progress(chunk: List[Dict[str, Any]]) -> None:
+                progressbar.update(len(chunk))
+
+            results: List[Result] = files.scan(
+                client=ctx.obj["client"],
+                cache=ctx.obj["cache"],
+                matches_ignore=config.matches_ignore,
+                banlisted_detectors=config.banlisted_detectors,
+                all_policies=config.all_policies,
+                verbose=config.verbose,
+                mode_header=SupportedScanMode.ARCHIVE.value,
+                on_file_chunk_scanned=update_progress,
+            )
+
+            scan = ScanCollection(id=path, type="archive_scan", results=results)
+
+            output_handler: OutputHandler = ctx.obj["output_handler"]
+            return output_handler.process_scan(scan)
