@@ -27,7 +27,6 @@ def get_files_from_paths(
     Create a scan object from files content.
 
     :param paths: List of file/dir paths from the command
-    :param paths_ignore: List of file/dir paths to ignore (glob pattern)
     :param recursive: Recursive option
     :param yes: Skip confirmation option
     :param verbose: Option that displays filepaths as they are scanned
@@ -76,7 +75,7 @@ def get_filepaths(
                 )
             top_dir = Path(path)
 
-            if is_git_dir(path) and not ignore_git:
+            if not ignore_git and is_git_dir(path):
                 _targets = {os.path.join(path, target) for target in git_ls(path)}
             else:
                 _targets = {str(target) for target in top_dir.rglob(r"*")}
