@@ -36,13 +36,10 @@ class Line(NamedTuple):
     Line object making easier to handle line
     by line display.
 
-    :param content: Content of the line
-    :param category: The line category [+|-| ]
-        (addition, deletion, untouched)
-    :param pre_index: Line index
-        (deletion for patches, line index for files)
-    :param post_index: Line index
-        (addition for patches)
+    - content: Content of the line
+    - category: The line category [+|-| ] (addition, deletion, untouched)
+    - pre_index: Line index (deletion for patches, line index for files)
+    - post_index: Line index (addition for patches)
     """
 
     content: str
@@ -105,3 +102,15 @@ def format_line_count(line_count: Union[int, None], padding: int) -> str:
 
 def display_error(msg: str) -> None:
     click.echo(format_text(msg, STYLE["error"]), err=True)
+
+
+_VALIDITY_TEXT_FOR_ID = {
+    "cannot_check": "Cannot Check",
+    "invalid": "Invalid",
+    "unknown": "Unknown",
+    "valid": "Valid",
+}
+
+
+def translate_validity(validity_id: Optional[str]) -> str:
+    return _VALIDITY_TEXT_FOR_ID[validity_id or "unknown"]
